==> 6.5.0-0-202303290841qtwebengine-everywhere-src-6.5.0.zip: 6.5.0/Src/qtwebengine/src/3rdparty/chromium/ui/ozone/platform/wayland/wayland_utils.cc <==
// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/ozone/platform/wayland/wayland_utils.h"

#include "ui/gfx/image/image_skia.h"
#include "ui/ozone/platform/wayland/host/wayland_connection.h"
#include "ui/ozone/platform/wayland/host/wayland_keyboard.h"
#include "ui/ozone/platform/wayland/host/wayland_seat.h"
#include "ui/ozone/platform/wayland/host/wayland_toplevel_window.h"

namespace ui {

namespace {

class WaylandScopedDisableClientSideDecorationsForTest
    : public PlatformUtils::ScopedDisableClientSideDecorationsForTest {
 public:
  WaylandScopedDisableClientSideDecorationsForTest() {
    WaylandToplevelWindow::AllowSettingDecorationInsetsForTest(false);
  }

  ~WaylandScopedDisableClientSideDecorationsForTest() override {
    WaylandToplevelWindow::AllowSettingDecorationInsetsForTest(true);
  }
};

}  // namespace

WaylandUtils::WaylandUtils(WaylandConnection* connection)
    : connection_(connection) {}

WaylandUtils::~WaylandUtils() = default;

gfx::ImageSkia WaylandUtils::GetNativeWindowIcon(intptr_t target_window_id) {
  return {};
}

std::string WaylandUtils::GetWmWindowClass(
    const std::string& desktop_base_name) {
  return desktop_base_name;
}

std::unique_ptr<PlatformUtils::ScopedDisableClientSideDecorationsForTest>
WaylandUtils::DisableClientSideDecorationsForTest() {
  return std::make_unique<WaylandScopedDisableClientSideDecorationsForTest>();
}

void WaylandUtils::OnUnhandledKeyEvent(const KeyEvent& key_event) {
  auto* seat = connection_->seat();
  if (!seat)
    return;
  auto* keyboard = seat->keyboard();
  if (!keyboard)
    return;
  keyboard->OnUnhandledKeyEvent(key_event);
}

}  // namespace ui

==> 6.6.3-0-202403191840qtwebengine-everywhere-src-6.6.3.zip: 6.6.3/Src/qtwebengine/src/3rdparty/chromium/ui/ozone/platform/wayland/wayland_utils.cc <==
// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/ozone/platform/wayland/wayland_utils.h"

#include "ui/gfx/image/image_skia.h"
#include "ui/ozone/platform/wayland/host/wayland_connection.h"
#include "ui/ozone/platform/wayland/host/wayland_keyboard.h"
#include "ui/ozone/platform/wayland/host/wayland_seat.h"
#include "ui/ozone/platform/wayland/host/wayland_toplevel_window.h"

namespace ui {

namespace {

class WaylandScopedDisableClientSideDecorationsForTest
    : public PlatformUtils::ScopedDisableClientSideDecorationsForTest {
 public:
  WaylandScopedDisableClientSideDecorationsForTest() {
    wl::AllowClientSideDecorationsForTesting(false);
  }

  ~WaylandScopedDisableClientSideDecorationsForTest() override {
    wl::AllowClientSideDecorationsForTesting(true);
  }
};

}  // namespace

WaylandUtils::WaylandUtils(WaylandConnection* connection)
    : connection_(connection) {}

WaylandUtils::~WaylandUtils() = default;

gfx::ImageSkia WaylandUtils::GetNativeWindowIcon(intptr_t target_window_id) {
  return {};
}

std::string WaylandUtils::GetWmWindowClass(
    const std::string& desktop_base_name) {
  return desktop_base_name;
}

std::unique_ptr<PlatformUtils::ScopedDisableClientSideDecorationsForTest>
WaylandUtils::DisableClientSideDecorationsForTest() {
  return std::make_unique<WaylandScopedDisableClientSideDecorationsForTest>();
}

void WaylandUtils::OnUnhandledKeyEvent(const KeyEvent& key_event) {
  auto* seat = connection_->seat();
  if (!seat)
    return;
  auto* keyboard = seat->keyboard();
  if (!keyboard)
    return;
  keyboard->OnUnhandledKeyEvent(key_event);
}

}  // namespace ui
